==> openshift-model-monitoring-5.7.3-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ServiceMonitorSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceMonitorSpecFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public A setToEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public A addToEndpoints(io.fabric8.openshift.api.model.monitoring.v1.Endpoint... items);
  public A addAllToEndpoints(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> items);
  public A removeFromEndpoints(io.fabric8.openshift.api.model.monitoring.v1.Endpoint... items);
  public A removeAllFromEndpoints(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> items);
  public A removeMatchingFromEndpoints(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEndpoints instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> getEndpoints();
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> buildEndpoints();
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildFirstEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildLastEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildMatchingEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  public java.lang.Boolean hasMatchingEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  public A withEndpoints(java.util.List<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> endpoints);
  public A withEndpoints(io.fabric8.openshift.api.model.monitoring.v1.Endpoint... endpoints);
  public java.lang.Boolean hasEndpoints();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> addNewEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> addNewEndpointLike(io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> setNewEndpointLike(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editFirstEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editLastEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editMatchingEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  public java.lang.String getJobLabel();
  public A withJobLabel(java.lang.String jobLabel);
  public java.lang.Boolean hasJobLabel();
  
  /**
   * Method is deprecated. use withJobLabel instead.
   */
  @java.lang.Deprecated
  public A withNewJobLabel(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector getNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector buildNamespaceSelector();
  public A withNamespaceSelector(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector namespaceSelector);
  public java.lang.Boolean hasNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector item);
  public A addToPodTargetLabels(java.lang.Integer index,java.lang.String item);
  public A setToPodTargetLabels(java.lang.Integer index,java.lang.String item);
  public A addToPodTargetLabels(java.lang.String... items);
  public A addAllToPodTargetLabels(java.util.Collection<java.lang.String> items);
  public A removeFromPodTargetLabels(java.lang.String... items);
  public A removeAllFromPodTargetLabels(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getPodTargetLabels();
  public java.lang.String getPodTargetLabel(java.lang.Integer index);
  public java.lang.String getFirstPodTargetLabel();
  public java.lang.String getLastPodTargetLabel();
  public java.lang.String getMatchingPodTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingPodTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public A withPodTargetLabels(java.util.List<java.lang.String> podTargetLabels);
  public A withPodTargetLabels(java.lang.String... podTargetLabels);
  public java.lang.Boolean hasPodTargetLabels();
  public A addNewPodTargetLabel(java.lang.String arg0);
  public java.lang.Long getSampleLimit();
  public A withSampleLimit(java.lang.Long sampleLimit);
  public java.lang.Boolean hasSampleLimit();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> editSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToTargetLabels(java.lang.Integer index,java.lang.String item);
  public A setToTargetLabels(java.lang.Integer index,java.lang.String item);
  public A addToTargetLabels(java.lang.String... items);
  public A addAllToTargetLabels(java.util.Collection<java.lang.String> items);
  public A removeFromTargetLabels(java.lang.String... items);
  public A removeAllFromTargetLabels(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getTargetLabels();
  public java.lang.String getTargetLabel(java.lang.Integer index);
  public java.lang.String getFirstTargetLabel();
  public java.lang.String getLastTargetLabel();
  public java.lang.String getMatchingTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public A withTargetLabels(java.util.List<java.lang.String> targetLabels);
  public A withTargetLabels(java.lang.String... targetLabels);
  public java.lang.Boolean hasTargetLabels();
  public A addNewTargetLabel(java.lang.String arg0);
  public java.lang.Long getTargetLimit();
  public A withTargetLimit(java.lang.Long targetLimit);
  public java.lang.Boolean hasTargetLimit();
  public interface EndpointsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.EndpointFluent<io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<N>>{
    public N and();
    public N endEndpoint();
    
  }
  public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}

==> openshift-model-monitoring-5.10.0-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/ServiceMonitorSpecFluent.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.lang.Long;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface ServiceMonitorSpecFluent<A extends io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public A setToEndpoints(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public A addToEndpoints(io.fabric8.openshift.api.model.monitoring.v1.Endpoint... items);
  public A addAllToEndpoints(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> items);
  public A removeFromEndpoints(io.fabric8.openshift.api.model.monitoring.v1.Endpoint... items);
  public A removeAllFromEndpoints(java.util.Collection<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> items);
  public A removeMatchingFromEndpoints(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEndpoints instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> getEndpoints();
  public java.util.List<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> buildEndpoints();
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildFirstEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildLastEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.Endpoint buildMatchingEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  public java.lang.Boolean hasMatchingEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  public A withEndpoints(java.util.List<io.fabric8.openshift.api.model.monitoring.v1.Endpoint> endpoints);
  public A withEndpoints(io.fabric8.openshift.api.model.monitoring.v1.Endpoint... endpoints);
  public java.lang.Boolean hasEndpoints();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> addNewEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> addNewEndpointLike(io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> setNewEndpointLike(java.lang.Integer index,io.fabric8.openshift.api.model.monitoring.v1.Endpoint item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editEndpoint(java.lang.Integer index);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editFirstEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editLastEndpoint();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<A> editMatchingEndpoint(java.util.function.Predicate<io.fabric8.openshift.api.model.monitoring.v1.EndpointBuilder> predicate);
  public java.lang.String getJobLabel();
  public A withJobLabel(java.lang.String jobLabel);
  public java.lang.Boolean hasJobLabel();
  
  /**
   * Method is deprecated. use withJobLabel instead.
   */
  @java.lang.Deprecated
  public A withNewJobLabel(java.lang.String arg0);
  
  /**
   * This method has been deprecated, please use method buildNamespaceSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector getNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector buildNamespaceSelector();
  public A withNamespaceSelector(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector namespaceSelector);
  public java.lang.Boolean hasNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> editNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelector item);
  public A addToPodTargetLabels(java.lang.Integer index,java.lang.String item);
  public A setToPodTargetLabels(java.lang.Integer index,java.lang.String item);
  public A addToPodTargetLabels(java.lang.String... items);
  public A addAllToPodTargetLabels(java.util.Collection<java.lang.String> items);
  public A removeFromPodTargetLabels(java.lang.String... items);
  public A removeAllFromPodTargetLabels(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getPodTargetLabels();
  public java.lang.String getPodTargetLabel(java.lang.Integer index);
  public java.lang.String getFirstPodTargetLabel();
  public java.lang.String getLastPodTargetLabel();
  public java.lang.String getMatchingPodTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingPodTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public A withPodTargetLabels(java.util.List<java.lang.String> podTargetLabels);
  public A withPodTargetLabels(java.lang.String... podTargetLabels);
  public java.lang.Boolean hasPodTargetLabels();
  public A addNewPodTargetLabel(java.lang.String arg0);
  public java.lang.Long getSampleLimit();
  public A withSampleLimit(java.lang.Long sampleLimit);
  public java.lang.Boolean hasSampleLimit();
  
  /**
   * This method has been deprecated, please use method buildSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildSelector();
  public A withSelector(io.fabric8.kubernetes.api.model.LabelSelector selector);
  public java.lang.Boolean hasSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> withNewSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> withNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> editSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> editOrNewSelector();
  public io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<A> editOrNewSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToTargetLabels(java.lang.Integer index,java.lang.String item);
  public A setToTargetLabels(java.lang.Integer index,java.lang.String item);
  public A addToTargetLabels(java.lang.String... items);
  public A addAllToTargetLabels(java.util.Collection<java.lang.String> items);
  public A removeFromTargetLabels(java.lang.String... items);
  public A removeAllFromTargetLabels(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getTargetLabels();
  public java.lang.String getTargetLabel(java.lang.Integer index);
  public java.lang.String getFirstTargetLabel();
  public java.lang.String getLastTargetLabel();
  public java.lang.String getMatchingTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingTargetLabel(java.util.function.Predicate<java.lang.String> predicate);
  public A withTargetLabels(java.util.List<java.lang.String> targetLabels);
  public A withTargetLabels(java.lang.String... targetLabels);
  public java.lang.Boolean hasTargetLabels();
  public A addNewTargetLabel(java.lang.String arg0);
  public java.lang.Long getTargetLimit();
  public A withTargetLimit(java.lang.Long targetLimit);
  public java.lang.Boolean hasTargetLimit();
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface EndpointsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.EndpointFluent<io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.EndpointsNested<N>>{
    public N and();
    public N endEndpoint();
    
  }
  public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.monitoring.v1.NamespaceSelectorFluent<io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.NamespaceSelectorNested<N>>{
    public N and();
    public N endNamespaceSelector();
    
  }
  public interface SelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.openshift.api.model.monitoring.v1.ServiceMonitorSpecFluent.SelectorNested<N>>{
    public N and();
    public N endSelector();
    
  }
  
}
